@@ -134,7 +134,7 @@ package Date::Time2fmtstr;
 use strict;
 #use warnings;
 use vars qw(@ISA @EXPORT $VERSION);
-$VERSION = '1.01';
+$VERSION = '1.02';
 
 require Exporter;
 
@@ -272,6 +272,8 @@ sub _toc_yyyy   #4-DIGIT YEAR
 sub _toc_yy
 {
 	my $myyr = $inputs[5];
+	return "Invalid Year ($myyr)! "  unless ($myyr =~ /^[0-9]+$/o);
+	$myyr -= 100  while ($myyr >= 100);
 	return  '0'.$myyr  if ($myyr < 10);
 	return $myyr;
 }
